.. _DataManagement:

API Documentation
=================

.. module:: wapor_algorithms

For normal use, all you will have to do to get started is::

    from wpDataManagement import DataManagement

This will import the following:

* The class :DataManagement:`DataManagement` and its subclasses

The Data Management for Water Productivity class
------------------------------------------------

.. autoclass:: DataManagement
    :members:


